@@ -3,7 +3,7 @@ BEGIN {
   $File::Serialize::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: DWIM file serialization/deserialization
-$File::Serialize::VERSION = '0.1.0';
+$File::Serialize::VERSION = '0.2.0';
 use strict;
 use warnings;
 
@@ -18,9 +18,9 @@ our @EXPORT = qw/ serialize_file deserialize_file /;
 our %serializers = (
     YAML => {
         extensions => [ 'yml', 'yaml' ],  # first extension is the canonical one
-        init => 'YAML',
-        serialize   => sub { YAML::Dump(shift) },  # arguments: $data, $options
-        deserialize => sub { YAML::Load(shift) },  # arguments: $data, $options
+        init => 'YAML::Tiny',
+        serialize   => sub { YAML::Tiny->new(shift)->write_string },  # arguments: $data, $options
+        deserialize => sub { YAML::Tiny->new->read_string(shift)->[0] },  # arguments: $data, $options
     },
     JSON => {
         extensions => [ 'json', 'js' ],
@@ -29,7 +29,9 @@ our %serializers = (
             # arguments $options, $serialize
             my $options = shift; 
             my %groomed;
-            $groomed{pretty} = $options->{pretty} if defined $options->{pretty};
+            for my $k( qw/ pretty canonical / ) {
+                $groomed{$k} = $options->{$k} if defined $options->{$k};
+            }
 
             return \%groomed;
         },
@@ -125,7 +127,7 @@ File::Serialize - DWIM file serialization/deserialization
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -168,7 +170,7 @@ yaml, yml
 
 =item module used
 
-L<YAML>
+L<YAML::Tiny>
 
 =item supported options
 
@@ -190,7 +192,7 @@ L<JSON::MaybeXS>
 
 =item supported options
 
-pretty
+pretty, canonical
 
 =back
 
@@ -238,6 +240,10 @@ appended to the file. Requires the parameter C<format> to be given as well.
 
 The serialization will be formatted for human consumption.
 
+=item canonical => $boolean
+
+Serializes the data using its canonical representation.
+
 =back
 
 =head1 FUNCTIONS
